@@ -28,6 +28,17 @@ sub blah {
     print("MEOW!\n");
 }
 
-blah("libhugs-libfrankie-dev");
+sub blah1 {
+    my @links1;
+    my @links2 = split("\n", "a\nb");
+    if (@links1 == @links2) {
+	    print("YEP\n");
+    } else {
+	    print("NOPE\n");
+    }
+}
+
+#blah("libhugs-libfrankie-dev");
 #print(installable_config_shipper("doc"));
 #print("\n");
+blah1();
